﻿namespace Phoenix.Main.Frame
{
    using System;
    using System.Windows.Forms;

    using Phoenix.Log;
    using Phoenix.Log.Writer;

    using WeifenLuo.WinFormsUI.Docking;

    /// <summary>
    /// Contains the logs.
    /// </summary>
    public partial class LogFrame : DockContent
    {
        #region Fields

        private ILogger logger;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="LogFrame"/> class.
        /// </summary>
        public LogFrame()
        {
            InitializeComponent();
            if (LogManager.IsConfigured)
            {
                this.logger = LogManager.GetLogger(typeof(LogFrame));
                this.logger.Logged += logger_Logged;

                this.logger.Info("Phoenix 2 has started!");
            }
            else
                lv_Logs.Items.Add(new ListViewItem("Impossible to load the logs!"));
        }

        #endregion Constructors

        #region Methods

        private void logger_Logged(object sender, LogEventArgs e)
        {
            ListViewItem itemDate = new ListViewItem(DateTime.Now.ToString());
            ListViewItem.ListViewSubItem itemType = new ListViewItem.ListViewSubItem(itemDate, e.Stamp.ToString());
            ListViewItem.ListViewSubItem itemMsg = new ListViewItem.ListViewSubItem(itemDate, e.Message);

            itemDate.SubItems.Add(itemType);
            itemDate.SubItems.Add(itemMsg);

            switch (e.Stamp)
            {
                case Stamp.Fatal:
                case Stamp.Error:
                    itemDate.ImageKey = "error";
                    break;
                case Stamp.Warning:
                    itemDate.ImageKey = "warning";
                    break;
                case Stamp.Info:
                    itemDate.ImageKey = "info";
                    break;
                case Stamp.Flag:
                    itemDate.ImageKey = "flag";
                    break;
                case Stamp.Debug:
                    itemDate.ImageKey = "debug";
                    break;
                default:
                    break;
            }
            lv_Logs.Items.Add(itemDate);
        }

        #endregion Methods
    }
}