﻿namespace Phoenix.Model.Bll.Interface
{
    using System.Collections.Generic;

    using Phoenix.Model.Bll.Domain;

    public interface IPatientRepository : IRepository<Patient>
    {
        #region Methods

        /// <summary>
        /// Clears the specified patient from repository.
        /// That's, it'll remove all references of the specified
        /// patient from the repository
        /// </summary>
        /// <param name="patient">The patient to clear from repository.</param>
        void ClearFromRepository(Patient patient);

        /// <summary>
        /// Gets the patient with the specified ID.
        /// </summary>
        /// <param name="id">The id.</param>
        /// <returns></returns>
        Patient GetById(long id);

        /// <summary>
        /// Gets the random patient for debugging purpose.
        /// </summary>
        /// <returns></returns>
        Patient GetDebugPatient();

        /// <summary>
        /// Searches the items in the database that respect the specified criterion.
        /// Every not empty properties are considered as criterion for the search.
        /// Every empty (null or with default values) are excluded of the search.
        /// The search is optimistic on text. For instance, that'll search on all
        /// the tuples that contains the text and not that has exactly the specified name.
        /// </summary>
        /// <param name="criterion">The criterion.</param>
        /// <returns>
        /// A list of the items that respect the criterion.
        /// </returns>
        IList<Patient> Search(Patient criterion);

        #endregion Methods
    }
}