﻿using System;

using Phoenix.Model.Sessions;

using StructureMap;

namespace Phoenix.Model
{
    /// <summary>
    /// Provides isntances for demanded interface.
    /// It is an entry point for IoC.
    /// </summary>
    public class Gui
    {
        #region Properties

        private static bool IsLoaded
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Gets the right instance for the specified type.
        /// </summary>
        /// <typeparam name="T">The type of the instance to return that fits the specified interface.</typeparam>
        /// <returns>The right instance related to the specified interface</returns>
        public static T Get<T>()
        {
            try
            {
                if (!IsLoaded)
                    Load();

                return ObjectFactory.GetInstance<T>();
            }
            catch (Exception ex)
            {
                string msg = string.Format("Impossible to find an instance for this interface '{0}'", typeof(T));
                throw new InvalidOperationException(msg, ex);
            }
        }

        private static void Load()
        {
            ObjectFactory.Configure(e => e.For<ISessionGui>().Use<SessionGui>());
            IsLoaded = true;
        }

        #endregion Methods
    }
}