﻿namespace Phoenix.Model.Management
{
    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces.Manager;

    /// <summary>
    /// The bmi manager will manage the bmi list of a patient
    /// </summary>
    public class BmiModel
    {
        #region Fields

        private IBmiManagerPresenter presenter;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="BmiModel"/> class.
        /// </summary>
        /// <param name="presenter">The view.</param>
        public BmiModel(IBmiManagerPresenter presenter)
        {
            this.presenter = presenter;
            this.presenter.Refreshed += (sender, e) => this.Update();
            this.presenter.Deleted += (sender, e) => this.Delete(e.Data);
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Deletes the specified bmi from the bmi history of the patient.
        /// </summary>
        /// <param name="bmi">The bmi to remove.</param>
        private void Delete(BMI bmi)
        {
            Assert.IsNotNull(bmi, "bmi");
            Assert.IsTrue((this.presenter.Patient != null), "Impossible to update an patient whose is unset!");

            int bmiBefore = this.presenter.Patient.BmiHistory.Length;

            this.presenter.Patient.Remove(bmi);

            int bmiAfter = this.presenter.Patient.BmiHistory.Length;

            RepositoryFactory.Get<IPatientRepository>().Update(this.presenter.Patient);
            Assert.IsTrue((bmiBefore > bmiAfter), "No Bmi entry was deleted!");
        }

        /// <summary>
        /// Commit all the changes made for the patient of this instance.
        /// </summary>
        private void Update()
        {
            Assert.IsNotNull(this.presenter.Patient, "Patient");
            RepositoryFactory.Get<IPatientRepository>().Update(this.presenter.Patient);
        }

        #endregion Methods
    }
}