﻿namespace Phoenix.Presenter.Management
{
    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Model.Management;
    using Phoenix.Presenter.Interfaces.Input;

    /// <summary>
    /// Provides features to manage the insurance.
    /// </summary>
    public class InsuranceModel : Manager<Insurance>
    {
        #region Fields

        private IInsuranceInputPresenter presenter;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="InsuranceModel"/> class.
        /// </summary>
        /// <param name="presenter">The presenter.</param>
        public InsuranceModel(IInsuranceInputPresenter presenter)
            : base(RepositoryFactory.Get<IInsuranceRepository>())
        {
            this.presenter = presenter;
            this.presenter.Inserted += (sender, e) => this.Insert(this.presenter.ItemToManage);
            this.presenter.Updated += (sender, e) => this.Update(this.presenter.ItemToManage);
            this.presenter.Deleted += (sender, e) => this.Delete(this.presenter.ItemToManage);
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns><c>True</c> if the data have passed the validation;
        /// otherwise <c>False</c></returns>
        public override bool ValidateData()
        {
            var result = true;
            Assert.IsNotNull(this.presenter.ItemToManage, "ItemToManage", "The item to manage wasn't set before validation!");
            string title = presenter.ItemToManage.Title;
            if (string.IsNullOrEmpty(title))
            {
                string msg = "An insurance can't have an empty name!";
                this.presenter.SetError(InsuranceFailedOn.EmptyTitle, msg);
                result = false;
            }
            return result;
        }

        /// <summary>
        /// Process to execute when a delete is raised.
        /// </summary>
        /// <param name="item">The item to delete.</param>
        protected override void Delete(Insurance item)
        {
            if (this.Repository.IsReferenced(this.presenter.ItemToManage))
            {
                this.presenter.SetError(InsuranceFailedOn.Referenced, "Impossible to delete this item, it is referenced somewhere else");
            }
            else
            {
                base.Delete(item);
            }
        }

        #endregion Methods
    }
}