﻿namespace Phoenix.Model.Core.Management
{
    using System.Linq;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Model.Management;
    using Phoenix.Presenter.Interfaces.Manager;

    /// <summary>
    /// Handle prescription management
    /// </summary>
    public class PrescriptionModel : Manager<Patient>
    {
        #region Fields

        private IPrescriptionManagerPresenter presenter;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PrescriptionModel"/> class.
        /// </summary>
        /// <param name="presenter">The presenter.</param>
        public PrescriptionModel(IPrescriptionManagerPresenter presenter)
            : base(RepositoryFactory.Get<IPatientRepository>())
        {
            this.presenter = presenter;
            this.presenter.Updated += (sender, e) => Update();
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Gets the default user of the application.
        /// </summary>
        /// <returns></returns>
        public User GetDefaultUser()
        {
            var repository = RepositoryFactory.Get<IUserRepository>();
            return repository.GetDefaultUser();
        }

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns>
        /// 	<c>True</c> if the data have passed the validation;
        /// otherwise <c>False</c>
        /// </returns>
        public override bool ValidateData()
        {
            foreach (var prescription in this.presenter.Patient.Prescriptions)
                prescription.Drugs = prescription.Drugs.Distinct().ToList();

            return true;
        }

        private void Update()
        {
            if (this.ValidateData())
            {
                this.presenter.Patient.Prescriptions =
                    (from each in this.presenter.Patient.Prescriptions
                     orderby each.CreationDate ascending
                     select each).ToArray();

                this.Repository.Update(this.presenter.Patient);
                this.presenter.RefreshGui();
            }
        }

        #endregion Methods
    }
}