﻿namespace Phoenix.Model.Management
{
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Model.Dal.Repositories;
    using Phoenix.Presenter;
    using Phoenix.Presenter.Interfaces.Input;

    /// <summary>
    /// Provides features to manage a family link type
    /// </summary>
    public class RelationTypeModel
    {
        #region Fields

        IRelationTypeInputPresenter presenter;
        IRelationTypeRepository repository = RepositoryFactory.Get<RelationTypeRepository>();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="RelationTypeModel"/> class.
        /// </summary>
        /// <param name="presenter">The view.</param>
        public RelationTypeModel(IRelationTypeInputPresenter presenter)
        {
            this.presenter = presenter;
            this.presenter.Inserted += (sender, args) => this.Create();
            this.presenter.Updated += (sender, args) => this.Update();
            this.presenter.Deleted += (sender, args) => this.Delete();
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns></returns>
        public bool ValidateData()
        {
            this.presenter.ClearError();
            bool result = true;
            if (string.IsNullOrEmpty(this.presenter.ItemToManage.Title))
            {
                this.presenter.SetError(RelationTypeFailedOn.EmptyName, "The relation should have a name");
                result = false;
            }
            if (string.IsNullOrEmpty(this.presenter.ItemToManage.UpsideDown.Title))
            {
                this.presenter.SetError(RelationTypeFailedOn.UpsideDownEmptyName, "The upside down relation should have a name!");
                result = false;
            }
            return result;
        }

        /// <summary>
        /// Creates this instance.
        /// </summary>
        private void Create()
        {
            repository.Create(this.presenter.ItemToManage);
            AppContext.NotifyDataChanged();
        }

        /// <summary>
        /// Execute a deletion
        /// </summary>        
        private void Delete()
        {
            if (this.repository.IsReferenced(this.presenter.ItemToManage))
            {
                this.presenter.SetError(RelationTypeFailedOn.Referenced, "Impossible to delete this item, it is referenced somewhere else.");
            }
            else
            {
                repository.Delete(this.presenter.ItemToManage);
                AppContext.NotifyDataChanged();
            }
        }

        /// <summary>
        /// Updates this instance.
        /// </summary>
        private void Update()
        {
            repository.Update(this.presenter.ItemToManage);
            AppContext.NotifyDataChanged();
        }

        #endregion Methods
    }
}