﻿namespace Phoenix.Model.Dal.Repositories
{
    using System.Collections.Generic;
    using System.Linq;

    using NHibernate.Linq;

    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;

    /// <summary>
    /// Manage the Pathology entities into the repository
    /// </summary>
    public class PathologyRepository : Repository<Pathology>, IPathologyRepository
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PathologyRepository"/> class.
        /// </summary>
        public PathologyRepository()
            : base("Pathology", "Title")
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Determines whether the specified item is referenced.
        /// </summary>
        /// <param name="item">The item.</param>
        /// <returns>
        /// 	<c>true</c> if the specified item is referenced; otherwise, <c>false</c>.
        /// </returns>
        public override bool IsReferenced(Pathology item)
        {
            return (from Patient p in this.Session.Linq<Patient>()
                    select p.Pathologies into pathologicEvent

                    from PathologicEvent pe in pathologicEvent
                    where pe.Pathology == item
                    select pe).Count() > 0;
        }

        /// <summary>
        /// Searches all the pathology with the specified pathology type.
        /// </summary>
        /// <param name="pathologyType">Type of the pathology.</param>
        /// <returns></returns>
        public IList<Pathology> Search(PathologyType pathologyType)
        {
            Assert.IsNotNull(pathologyType, "pathologyType");

            if (pathologyType.IsEmpty)
                return new List<Pathology>();

            return (from Pathology p in this.Session.Linq<Pathology>()
                    where p.Type == pathologyType
                    select p).ToList();
        }

        #endregion Methods
    }
}