﻿namespace Phoenix.Model.Dal.Repositories
{
    using System.Linq;

    using NHibernate.Linq;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;

    /// <summary>
    /// Manage the PathologicEvent entities into the repository
    /// </summary>
    public class PathologyTypeRepository : Repository<PathologyType>, IPathologyTypeRepository
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PathologyTypeRepository"/> class.
        /// </summary>
        public PathologyTypeRepository()
            : base("PathologyType", "Title")
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Determines whether the specified item is referenced.
        /// </summary>
        /// <param name="item">The item.</param>
        /// <returns>
        /// 	<c>true</c> if the specified item is referenced; otherwise, <c>false</c>.
        /// </returns>
        public override bool IsReferenced(PathologyType item)
        {
            return (from Pathology p in this.Session.Linq<Pathology>()
                    where p.Type == item
                    select p).Count() > 0;
        }

        #endregion Methods
    }
}