﻿namespace Phoenix.Plugin.Debug
{
    using System.Windows.Forms;

    using Phoenix.Plugins.Core;
    using Phoenix.Presenter.Interfaces.Input;
    using Phoenix.Presenter.Helpers;

    public class ApplicationPlugin : IApplicationPlugin
    {
        #region Methods

        public void Start(IPluginHost host)
        {
            var debugMenu = "menu_Debug";
            host.AddMenu(debugMenu, "Debug");
            host.AddSubmenu(debugMenu, "pg_AddReputation", "Add reputation", (sender, e) => this.DEBUG_AddReputation());
            host.AddSubmenu(debugMenu, "pg_AddInsurance", "Add insurance", (sender, e) => this.DEBUG_AddInsurance());
            host.AddSubmenu(debugMenu, "pg_AddPractice", "Add practice", (sender, e) => this.DEBUG_AddPractice());
            host.AddMenuSeparator(debugMenu);

            host.AddSubmenu(debugMenu, "pg_AddDoctor", "Add doctor", (sender, e) => this.DEBUG_Adddoctor());
            host.AddSubmenu(debugMenu, "pg_AddDoctorType", "Add doctor type", (sender, e) => this.DEBUG_AddDoctortype());
            host.AddMenuSeparator(debugMenu);

            host.AddSubmenu(debugMenu, "pg_AddRelation", "Add relation", (sender, e) => this.DEBUG_AddFamilyLink());
            host.AddSubmenu(debugMenu, "pg_AddRelationType", "Add relation type", (sender, e) => this.DEBUG_AddFamilyLinkType());
            host.AddMenuSeparator(debugMenu);

            host.AddSubmenu(debugMenu, "pg_AddDrug", "Add drug", (sender, e) => this.DEBUG_AddDrug());
            host.AddSubmenu(debugMenu, "pg_AddDrugType", "Add drug type", (sender, e) => this.DEBUG_AddDrugType());
            host.AddMenuSeparator(debugMenu);

            host.AddSubmenu(debugMenu, "pg_AddPathology", "Add pathology", (sender, e) => this.DEBUG_AddPathology());
            host.AddSubmenu(debugMenu, "pg_AddPathologyType", "Add pathology type", (sender, e) => this.DEBUG_AddPathologyType());
            host.AddMenuSeparator(debugMenu);

            host.AddSubmenu(debugMenu, "pg_ManageMacro", "Manage macro", (sender, e) => this.DEBUG_AddMacro());
            host.AddSubmenu(debugMenu, "pg_ManageKeywords", "Manage keywords", (sender, e) => this.DEBUG_ManageKeyword());
            host.AddSubmenu(debugMenu, "pg_ManageMedicalCardType", "Manage medical card type", (sender, e) => this.DEBUG_ManageMedicalCardType());
            host.AddMenuSeparator(debugMenu);

            host.AddSubmenu(debugMenu, "pg_Captcha", "Captcha", (sender, e) => this.DEBUG_Captcha());
            host.AddSubmenu(debugMenu, "pg_RefreshManagers", "Refresh managers", (sender, e) => this.DEBUG_RefreshManagers());
            host.AddSubmenu(debugMenu, "pg_ShowNewDoctorBox", "Show new DoctorBox", (sender, e) => this.DEBUG_DoctorBox());
            host.AddSubmenu(debugMenu, "pg_OpenCalendar", "Open Calendar", (sender, e) => this.DEBUG_OpenCalendar());
            host.AddSubmenu(debugMenu, "pg_OpenMeetingBox", "Open MeetingBox", (sender, e) => this.DEBUG_OpenMeetingBox());
            host.AddMenuSeparator(debugMenu);

        }

        private void DEBUG_Adddoctor()
        {
            IDoctorInputPresenter fr = GuiManager.Get<IDoctorInputPresenter>();
            fr.Usage = Usage.Insert;

            GuiManager.ShowDialog(fr);
            this.sideMenu.RefreshGui();
        }

        private void DEBUG_AddDoctortype()
        {
            IDoctorTypeInputPresenter dfr = GuiManager.Get<IDoctorTypeInputPresenter>();
            GuiManager.ShowDialog(dfr);
            this.sideMenu.RefreshGui();
        }

        private void DEBUG_AddDrugType()
        {
            IDrugTypeInputPresenter box = GuiManager.Get<IDrugTypeInputPresenter>();
            GuiManager.ShowDialog(box);
        }

        private void DEBUG_AddDrug()
        {
            IDrugInputPresenter box = GuiManager.Get<IDrugInputPresenter>();
            GuiManager.ShowDialog(box);
        }

        private void DEBUG_AddFamilyLink()
        {
            IPatientSearcher search = GuiManager.Get<IPatientSearcher>();
            DialogResult dr = GuiManager.ShowDialog(search);
            if (dr != DialogResult.OK) return;

            IRelationInputPresenter box = GuiManager.Get<IRelationInputPresenter>();
            box.Patient = search.SelectedItem as Patient;

            GuiManager.ShowDialog(box);
            this.sideMenu.RefreshGui();
        }

        private void DEBUG_AddFamilyLinkType()
        {
            IRelationTypeInputPresenter box = GuiManager.Get<IRelationTypeInputPresenter>();
            box.Usage = Usage.Insert;

            GuiManager.ShowDialog(box);
            this.sideMenu.RefreshGui();
        }

        private void DEBUG_AddInsurance()
        {
            IInsuranceInputPresenter box = GuiManager.Get<IInsuranceInputPresenter>();
            GuiManager.ShowDialog(box);
            this.sideMenu.RefreshGui();
        }

        private void DEBUG_AddMacro()
        {
            IMacroInputPresenter box = GuiManager.Get<IMacroInputPresenter>();
            GuiManager.ShowDialog(box);
        }

        private void DEBUG_AddPathologyType()
        {
            var box = GuiManager.Get<IPathologyTypeInputPresenter>();
            GuiManager.ShowDialog(box);
        }

        private void DEBUG_AddPathology()
        {
            var box = GuiManager.Get<IPathologyInputPresenter>();
            GuiManager.ShowDialog(box);
        }

        private void DEBUG_AddPractice()
        {
            IPracticeInputPresenter box = GuiManager.Get<IPracticeInputPresenter>();
            GuiManager.ShowDialog(box);
            this.sideMenu.RefreshGui();
        }

        private void DEBUG_AddReputation()
        {
            IReputationInputPresenter box = GuiManager.Get<IReputationInputPresenter>();
            GuiManager.ShowDialog(box);
            this.sideMenu.RefreshGui();
        }

        private void DEBUG_Captcha()
        {
            CaptchaBox fr = new CaptchaBox();
            fr.ConfirmationFailed += (x, y) => MessageBoxes.Asterisk("Captcha failed!");
            fr.ConfirmationSucceeded += (x, y) => MessageBoxes.Exclamation("Captcha succeeded!");
            fr.ShowDialog();
        }

        private void DEBUG_DoctorBox()
        {
            DoctorInput box = new DoctorInput();
            box.ShowDialog();
        }

        private void DEBUG_ManageKeyword()
        {
            IKeywordInputPresenter box = GuiManager.Get<IKeywordInputPresenter>();
            GuiManager.ShowDialog(box);
        }

        private void DEBUG_ManageMedicalCardType()
        {
            IMedicalCardTypeManagerPresenter box = GuiManager.Get<IMedicalCardTypeManagerPresenter>();
            GuiManager.ShowDialog(box);
        }

        private void DEBUG_OpenCalendar()
        {
            var form = new CalendarBox();
            form.ShowDialog();
        }

        private void DEBUG_OpenMeetingBox()
        {
            var form = new MeetingInput();
            form.ShowDialog();
        }

        private void DEBUG_RefreshManagers()
        {
            this.sideMenu.RefreshGui();
        }
        #endregion Methods
    }
}