﻿namespace Phoenix.Presenter.Interfaces
{
    using System;
    using System.Collections.Generic;

    using Phoenix.Helpers.Misc;
    using Phoenix.Model.Bll.Domain;

    public interface IMedicalCardManagerPresenter : IManager
    {
        #region Events

        /// <summary>
        /// Occurs when the view is refreshed.
        /// </summary>
        event EventHandler Refreshed;

        /// <summary>
        /// Occurs when a new type is created.
        /// </summary>
        event EventHandler<EventArgs<MedicalCardType>> TypeCreated;

        /// <summary>
        /// Occurs when a medical card type is removed.
        /// </summary>
        event EventHandler<EventArgs<MedicalCardType>> TypeRemoved;

        /// <summary>
        /// Occurs when a type is updated.
        /// </summary>
        event EventHandler<EventArgs<MedicalCardType>> TypeUpdated;

        /// <summary>
        /// Occurs when the patient is updated.
        /// </summary>
        event EventHandler Updated;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets the macros.
        /// </summary>
        /// <value>The macros.</value>
        IList<Macro> Macros
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the medical card types.
        /// </summary>
        /// <value>The medical card types.</value>
        IList<MedicalCardType> MedicalCardTypes
        {
            get;
            set;
        }

        #endregion Properties
    }
}