﻿namespace Phoenix.Presenter.Interfaces.Input
{
    using System;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Presenter.Helpers;

    #region Enumerations

    public enum DoctorTypeFailOn
    {
        /// <summary>
        /// There is no title fot the doctor type
        /// </summary>
        Title,
        /// <summary>
        /// The remark is a number
        /// </summary>
        RemarkIsNumber,
        /// <summary>
        /// This item is referenced somewhere else in the domain
        /// </summary>
        Referenced,
    }

    #endregion Enumerations

    /// <summary>
    /// GUI item to manage a doctor
    /// </summary>
    public interface IDoctorTypeInputPresenter
    {
        #region Events

        /// <summary>
        /// Occurs when user wants to delete an item.
        /// </summary>
        event EventHandler Deleted;

        /// <summary>
        /// Occurs when user wants to insert an item.
        /// </summary>
        event EventHandler Inserted;

        /// <summary>
        /// Occurs when user wants to update an item.
        /// </summary>
        event EventHandler Updated;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets the item to manage.
        /// </summary>
        /// <value>The item to manage.</value>
        DoctorType ItemToManage
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the usage of this GUI item.
        /// Should be Insert, Update or Delete.
        /// </summary>
        /// <value>The usage.</value>
        Usage Usage
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Clears previous error on validation failed.
        /// </summary>
        void ClearError();

        /// <summary>
        /// Closes this instance when work is finished.
        /// </summary>
        void Close();

        /// <summary>
        /// Sets an error message to explain why data validation failed.
        /// </summary>
        /// <param name="fail">The fail.</param>
        /// <param name="message">The message.</param>
        void SetError(DoctorTypeFailOn fail, string message);

        #endregion Methods
    }
}