﻿namespace Phoenix.View.Frame
{
    using System;
    using System.Collections.Generic;
    using System.Windows.Forms;

    using Phoenix.Helpers.Misc;
    using Phoenix.Helpers.Winforms;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Core.Management;
    using Phoenix.Presenter;
    using Phoenix.Presenter.Helpers;
    using Phoenix.Presenter.Interfaces;
    using Phoenix.Presenter.Interfaces.Input;
    using Phoenix.View.Input;

    /// <summary>
    /// Login form to enter nDoctor
    /// </summary>
    public partial class LoginForm : Form, ILoginPresenter
    {
        #region Fields

        private LoginModel model;
        private List<User> users = new List<User>();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="LoginForm"/> class.
        /// </summary>
        public LoginForm()
        {
            InitializeComponent();
            this.model = new LoginModel(this);
        }

        #endregion Constructors

        #region Events

        /// <summary>
        /// Occurs when a user is connecting.
        /// </summary>
        public event EventHandler<EventArgs<User>> UserConnecting;

        /// <summary>
        /// Occurs when [users loading].
        /// </summary>
        public event EventHandler UsersLoading;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets the password.
        /// </summary>
        /// <value>The password.</value>
        public string Password
        {
            get
            {
                return this.tb_Password.Text;

            }
        }

        /// <summary>
        /// Gets or sets a value indicating whether the connection succeeded.
        /// </summary>
        /// <value><c>true</c> if succeeded; otherwise, <c>false</c>.</value>
        public bool Succeeded
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the users.
        /// </summary>
        /// <value>The users.</value>
        public List<User> Users
        {
            get { return this.users; }
            set
            {
                this.users = value;
                this.bs_Users.DataSource = value;
            }
        }

        #endregion Properties

        #region Methods

        private void btn_NewUser_Click(object sender, EventArgs e)
        {
            var form = GuiManager.Get<IUserInputPresenter>();
            form.Usage = Usage.Insert;
            var dr = GuiManager.ShowDialog(form);

            if (dr != DialogResult.OK) return;

            this.bs_Users.Add(form.ItemToManage);
        }

        private void btn_OK_Click(object sender, EventArgs e)
        {
            var user = this.bs_Users.Current as User;
            if (user != null) this.OnUserConnecting(user);

            if (!this.Succeeded) MessageBoxes.Exclamation("Wrong password!");
            else
            {
                this.DialogResult = DialogResult.OK;
                AppContext.CurrentUser = user;
                this.Close();
            }
        }

        private void Login_Load(object sender, EventArgs e)
        {
            this.OnUsersLoading();
        }

        private void OnUserConnecting(User user)
        {
            this.UserConnecting.Raise(this, new EventArgs<User>(user));
        }

        private void OnUsersLoading()
        {
            this.UsersLoading.Raise(this);
        }

        #endregion Methods
    }
}