﻿namespace Phoenix.Presenter.Management.Controls
{
    using Phoenix.Model.Bll.Domain;

    /// <summary>
    /// Control that provides possibility to manage a reputation.
    /// </summary>
    public class ReputationManagerControl : GeneralManagerControl<Reputation>
    {
        #region Fields

        private Reputation reputation = new Reputation();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ReputationManagerControl"/> class.
        /// </summary>
        public ReputationManagerControl()
            : base()
        {
            this.Usage = Helpers.Usage.Insert;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the reputation.
        /// </summary>
        /// <value>The reputation.</value>
        public override Reputation ItemToManage
        {
            get
            {
                this.reputation.Title = this.tb_Name.Text;
                this.reputation.Remark = this.tb_Remarks.Text;
                return this.reputation;
            }
            set
            {
                this.reputation = value;
                this.tb_Name.Text = value.Title;
                this.tb_Remarks.Text = value.Remark;
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Sets an error message on empty name for the 
        /// reputation.
        /// </summary>
        /// <param name="msg">The MSG.</param>
        public void SetEmptyNameError(string msg)
        {
            this.ep_Error.SetError(this.tb_Name, msg);
        }

        #endregion Methods
    }
}