﻿namespace Phoenix.Helpers.Winforms
{
    using System;
    using System.Windows.Forms;

    /// <summary>
    /// Instantiation of this class will save the current cursor, replace it
    /// by the specified cursos in the Ctor and roll it back when Dispose() is called.
    /// </summary>
    public class CursorSnapshot : IDisposable
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="CursorSnapshot"/> class.
        /// </summary>
        /// <param name="cursor">The cursor.</param>
        public CursorSnapshot(Cursor cursor)
        {
            this.SavedCursor = cursor;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="CursorSnapshot"/> class.
        /// </summary>
        public CursorSnapshot()
        {
            this.SavedCursor = Cursor.Current;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets the saved cursor.
        /// </summary>
        /// <value>The saved cursor.</value>
        public Cursor SavedCursor
        {
            get;
            private set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
        /// </summary>
        public void Dispose()
        {
            Cursor.Current = this.SavedCursor;
        }

        /// <summary>
        ///// Rollbacks to the previous state of the cursor.
        /// </summary>
        public void Rollback()
        {
            Cursor.Current = this.SavedCursor;
        }

        /// <summary>
        /// Sets the mouse cursor with the specified type.
        /// </summary>
        /// <param name="cursor">The cursor.</param>
        public void Set(Cursor cursor)
        {
            Cursor.Current = cursor;
        }

        #endregion Methods
    }
}