﻿namespace Phoenix.Helpers.Winforms.Logging
{
    using System;
    using System.Collections.Generic;
    using System.Windows.Forms;

    using log4net;
    using log4net.Appender;
    using log4net.Core;
    using log4net.Repository.Hierarchy;

    /// <summary>
    /// Append the log into a ListView
    /// </summary>
    public class ListViewAppender : AppenderSkeleton
    {
        #region Fields

        private static ImageList _imageList;
        private static ListView _listView;

        #endregion Fields

        #region Properties

        private static IAppender[] Appenders
        {
            get
            {
                List<IAppender> appenders = new List<IAppender>();
                var hierarchy = LogManager.GetRepository() as Hierarchy;

                appenders.AddRange(hierarchy.Root.Appenders.ToArray());
                foreach (var log in LogManager.GetCurrentLoggers())
                {
                    appenders.AddRange((log.Logger as Logger).Appenders.ToArray());
                }

                return appenders.ToArray();
            }
        }

        private ImageList ImageList
        {
            get { return _imageList; }
            set { _imageList = value; }
        }

        private ListView ListView
        {
            get { return _listView; }
            set
            {
                IntPtr x = value.Handle;
                _listView = value;
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Configures this appender with the specified ListView.
        /// </summary>
        /// <param name="listView">The list view.</param>
        public static void Configure(ListView listView, ImageList images)
        {
            try
            {
                _listView = listView;
                listView.HideSelection = false;
                listView.Items.Clear();

                foreach (var appender in Appenders)
                {
                    if (appender is ListViewAppender) (appender as ListViewAppender).ListView = listView;
                }
            }
            catch (Exception) { throw; }
        }

        /// <summary>
        /// Appends the specified logging event.
        /// </summary>
        /// <param name="loggingEvent">The logging event.</param>
        protected override void Append(LoggingEvent loggingEvent)
        {
            if (this.ListView == null) return;
            if (this.ListView.InvokeRequired) this.ListView.Invoke((Action)delegate { Append(loggingEvent); });
            else this.Refresh(loggingEvent);
        }

        private void Refresh(LoggingEvent logEvent)
        {
            var item = new ListViewItem("", logEvent.Level.ToString().ToLower());
            item.SubItems.Add(logEvent.TimeStamp.ToString("[HH:mm:ss:fff]"));
            item.SubItems.Add(string.Format("{0} {1}"
                , logEvent.RenderedMessage
                , (logEvent.ExceptionObject == null) ? "" : logEvent.ExceptionObject.ToString()));

            this.ListView.Items.Add(item);
            this.ListView.Items[this.ListView.Items.Count - 1].EnsureVisible();
        }

        #endregion Methods
    }
}