﻿namespace Phoenix.Revision.Helpers
{
    using System;

    /// <summary>
    /// Encapsulate a Phoenix Revision
    /// </summary>
    public class Revision
    {
        #region Fields

        private static DateTime RevisionStartDate = new DateTime(2008, 1, 1, 0, 0, 0);

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="Revision"/> class.
        /// </summary>
        public Revision()
        {
            this.Value = this.CalculateRevision();
            this.RevisionDate = DateTime.Now;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Revision"/> class.
        /// </summary>
        /// <param name="date">The date.</param>
        public Revision(DateTime date)
        {
            this.Value = CalculateRevision(date);
            this.RevisionDate = date;
        }

        public Revision(int revision)
        {
            this.Value = revision;
            this.RevisionDate = CalculateRevisionDate(revision);
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the revision date.
        /// </summary>
        /// <value>The revision date.</value>
        public DateTime RevisionDate
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets or sets the value.
        /// </summary>
        /// <value>The value.</value>
        public int Value
        {
            get;
            private set;
        }

        #endregion Properties

        #region Methods

        public static int CalculateRevision(DateTime date)
        {
            TimeSpan span = date - RevisionStartDate;
            return (int)span.TotalHours / 3;
        }

        private int CalculateRevision()
        {
            return CalculateRevision(DateTime.Now);
        }

        public static DateTime CalculateRevisionDate(int revision)
        {
            TimeSpan span = new TimeSpan(revision * 3, 0, 0);
            return RevisionStartDate.Add(span);
        }

        #endregion Methods
    }
}